pilas.actores.mapa.Mapa

Package pilas :: Package actores :: Module mapa :: Class Mapa |
[hide private]
[frames] | no frames]

# Class Mapa

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
                  actor.Actor --+
                                |
                               Mapa

Known Subclasses:
  - mapatiled.MapaTiled

Representa una mapa de bloques rectangulares, ideal para crear escenarios de plataformas y mapas.

Instance Methods | [hide private]
__init__(self, grilla=None, x=0, y=0, filas=20, columnas=20) Inicializa el mapa. | source code
_convertir_en_int(self, valor) | source code
_generar_matriz_de_bloques(self, filas, columnas) | source code
_pintar_borde_de_grilla(self, fila, columna) | source code
convertir_de_coordenada_absoluta_a_coordenada_mapa(self, x, y) Toma un punto de pantalla y lo convierte a una coordenada dentro del mapa. | source code
es_bloque_solido(self, fila, columna) Indica si un determinado bloque es solido. | source code
es_punto_solido(self, x, y) Indica si una coordenada del escenario está sobre un bloque solido. | source code
es_punto_solido_coordenada_mapa(self, x, y) Consulta si un punto (x, y) está señalando un bloque sólido. | source code
obtener_distancia_al_suelo(self, x, y, maximo) Retorna la distancia en pixels desde un punto del mundo al suelo. | source code
obtener_numero_de_columna(self, x) Retorna el número de columna correspondiente a una coordenada horizontal. | source code
obtener_numero_de_fila(self, y) Retorna el número de fila correspondiente a una coordenada vertical. | source code
pintar_bloque(self, fila, columna, indice, es_bloque_solido=True) Define un bloque de la grilla. | source code
pintar_limite_de_bloques(self) Dibuja los bordes de cada bloque. | source code
Inherited from `actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `actualizar`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `eliminar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_x`, `get_y`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_x`, `set_y`, `set_z` Inherited from `actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
Inherited from `actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `x`, `y`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, grilla=None, x=0, y=0, filas=20, columnas=20) (Constructor) | source code
Inicializa el mapa. :param grilla: La imagen a utilizar cómo grilla con los bloques del escenario. :param x: Posición horizontal del mapa. :param y: Posición vertical del mapa. :param filas: Cantidad de filas que tendrá el mapa. :param columnas: Cantidad de columnas que tendrá el mapa. Overrides: estudiante.Estudiante.__init__

### convertir_de_coordenada_absoluta_a_coordenada_mapa(self, x, y) | source code
Toma un punto de pantalla y lo convierte a una coordenada dentro del mapa. :param x: Coordenada horizontal de pantalla. :param y: Coordenada vertical de pantalla.

### es_bloque_solido(self, fila, columna) | source code
Indica si un determinado bloque es solido. Los bloques sólidos se utilizan para marcar paredes y plataformas, es decir que son bloques que generalmente no se pueden sobrepasar. :param fila: La fila que se observará. :param columna: La columna que se observará.

### es_punto_solido(self, x, y) | source code
Indica si una coordenada del escenario está sobre un bloque solido. :param x: Posición horizontal a consultar. :param y: Posición vertical a consultar.

### es_punto_solido_coordenada_mapa(self, x, y) | source code
Consulta si un punto (x, y) está señalando un bloque sólido. :param x: Coordenada horizontal. :param y: Coordenada vertical.

### obtener_distancia_al_suelo(self, x, y, maximo) | source code
Retorna la distancia en pixels desde un punto del mundo al suelo. Es importante mostrar que las coordenadas x e y son coordenadas del mundo, no coordenadas de mouse o relativas al mapa. El argumento maximo es la cantidad de pixels que tomaremos como valor limite de la busqueda. Por ejemplo, si colocamos 100 como limite y la funcion nos retorna 100 es porque no encontró un suelo a menos de 100 pixels. Este límite existe por una cuestión de eficiencia. :param x: Posición horizontal de referencia. :param y: Posición vertical de referencia. :param maximo: Cantidad máxima de pixels a leer.

### obtener_numero_de_columna(self, x) | source code
Retorna el número de columna correspondiente a una coordenada horizontal. :param x: La coordenada horizontal (relativa al mapa, no a la pantalla).

### obtener_numero_de_fila(self, y) | source code
Retorna el número de fila correspondiente a una coordenada vertical. :param y: La coordenada vertical (relativa al mapa, no a la pantalla).

### pintar_bloque(self, fila, columna, indice, es_bloque_solido=True) | source code
Define un bloque de la grilla. :param fila: La fila que se definirá (comenzando desde 0). :param columna: La columna que se definirá (comenzando desde 0). :param indice: El número de cuadro referente a la grilla (comenzando desde 0). :param es_bloque_solido: True o False para indicar si los objetos físicos deberán colisionar con este bloque.